Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.emf.cdo.tests.model5/src/org/eclipse/emf/cdo/tests/model5/Model5Factory.java')
-rw-r--r--plugins/org.eclipse.emf.cdo.tests.model5/src/org/eclipse/emf/cdo/tests/model5/Model5Factory.java15
1 files changed, 12 insertions, 3 deletions
diff --git a/plugins/org.eclipse.emf.cdo.tests.model5/src/org/eclipse/emf/cdo/tests/model5/Model5Factory.java b/plugins/org.eclipse.emf.cdo.tests.model5/src/org/eclipse/emf/cdo/tests/model5/Model5Factory.java
index 1f552a50e4..10910507ed 100644
--- a/plugins/org.eclipse.emf.cdo.tests.model5/src/org/eclipse/emf/cdo/tests/model5/Model5Factory.java
+++ b/plugins/org.eclipse.emf.cdo.tests.model5/src/org/eclipse/emf/cdo/tests/model5/Model5Factory.java
@@ -150,11 +150,20 @@ public interface Model5Factory extends EFactory
Child createChild();
/**
* Returns a new object of class '<em>Gen List Of String</em>'.
* <!-- begin-user-doc --> <!-- end-user-doc -->
* @return a new object of class '<em>Gen List Of String</em>'.
* @generated
*/
+ WithCustomType createWithCustomType();
+
+ /**
+ * Returns a new object of class '<em>Gen List Of String</em>'.
+ * <!-- begin-user-doc --> <!-- end-user-doc -->
+ * @return a new object of class '<em>Gen List Of String</em>'.
+ * @generated
+ */
GenListOfString createGenListOfString();
/**
@@ -150,11 +150,20 @@ public interface Model5Factory extends EFactory
Child createChild();
/**
- * Returns a new object of class '<em>Gen List Of String</em>'.
- * <!-- begin-user-doc --> <!-- end-user-doc -->
- * @return a new object of class '<em>Gen List Of String</em>'.
+ * Returns a new object of class '<em>With Custom Type</em>'.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @return a new object of class '<em>With Custom Type</em>'.
* @generated
*/

Back to the top